Struct termit::widget::TextBox

source ·
pub struct TextBox<F, M, A: AppEvent> {
    pub active: bool,
    /* private fields */
}
A simplistic single line String editor.

It is suitable for simple use cases such as quick search input.

The cursor is always at the end. Backspace removes the last char.

Clicking on the TextBox activates it, clicking somewhere else deactivates it. You can override this by setting the active property on each update.

No cloning/moving, it will edit the &mut String in the model directly.

The last part of the string that fits is visible (tail).

Fields

active: bool

Implementations

source

impl<F, M, A: AppEvent> TextBox<F, M, A>where F: Fn(&mut M) -> Option<&mut String>,

source

pub fn new(accessor: F) -> Self

Create a textbox

The accessor specifies how to get to a mutable String reference in the model